@@ -32,7 +32,7 @@
 #include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -103,7 +103,7 @@ gnome_entry_get_type (void)
 	static GType object_type = 0;
 
 	if (object_type == 0) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeEntryClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
@@ -116,7 +116,7 @@ gnome_entry_get_type (void)
 			NULL			/* value_table */
 		};
 
-		static const GInterfaceInfo editable_info =
+		const GInterfaceInfo editable_info =
 		{
 			(GInterfaceInitFunc) gnome_entry_editable_init,	 /* interface_init */
 			NULL,			                         /* interface_finalize */
@@ -324,9 +324,7 @@ free_item (gpointer data, gpointer user_data)
 	struct item *item;
 
 	item = data;
-	if (item->text)
-		g_free (item->text);
-
+	g_free (item->text);
 	g_free (item);
 }
 
